@@ -2,7 +2,7 @@
  * Name:      CEA.cpp
  * Purpose:   EDID CEA-861 extension
  * Author:    Tomasz Pawlak (tomasz.pawlak@wp.eu)
- * Copyright: Tomasz Pawlak (C) 2014-2024
+ * Copyright: Tomasz Pawlak (C) 2014-2025
  * License:   GPLv3+
  **************************************************************/
 
@@ -62,7 +62,7 @@ const edi_field_t cea_hdr_cl::fields[] = {
    "1 = supports underscan." },
    {&EDID_cl::ByteVal, 0, offsetof(cea_hdr_t, info_blk)+1, 0, 1, F_BTE|F_HEX|F_RD, 0, 0xFF, "checksum",
    "Block checksum:\n [sum_of_bytes(0-127) mod 256] + checkum_field_val must be equal to zero.\n\n"
-   "NOTE: this byte is physically located at the end of the block (offset 127)"}
+   "NOTE: this byte is physically located at the end of the extension block (offset 127)"}
 };
 
 #pragma GCC diagnostic ignored "-Wunused-parameter"
