@@ -2,7 +2,7 @@
  * Name:      EDID_base.cpp
  * Purpose:   EDID base data groups
  * Author:    Tomasz Pawlak (tomasz.pawlak@wp.eu)
- * Copyright: Tomasz Pawlak (C) 2014-2024
+ * Copyright: Tomasz Pawlak (C) 2014-2025
  * License:   GPLv3+
  **************************************************************/
 
@@ -274,9 +274,10 @@ const edi_field_t edibase_cl::fields[] = {
    "EDID revision" },
    {&EDID_cl::ByteVal, 0, offsetof(edid_t, edid_rev)+1, 0, 1, F_BTE|F_INT|F_RD, 0, 3, "num_extblk",
    "Number of extension blocks.\n\n"
-   "If num_extblk==0, extension block is not saved, regardles of whether it was loaded or not.\n"
-   "If num_extblk==1, and the extension block is not present, Saving/Exporting functions will fail."
-   "\n\nNOTE: wxEDID supports only 1 extension of type CTA-861" },
+   "If num_extblk==0, extension block is not saved/exported, regardles of whether it was loaded or not.\n"
+   "If num_extblk==1, and the extension block is not present, Saving/Exporting functions will fail.\n"
+   "If num_extblk >1, ERROR: wxEDID supports only 1 extension of type CTA-861, "
+   "Saving/Exporting functions will fail."},
    {&EDID_cl::ByteVal, 0, offsetof(edid_t, edid_rev)+2, 0, 1, F_BTE|F_HEX|F_RD, 0, 255, "checksum",
    "Block checksum:\n [sum_of_bytes(0-127) mod 256] + checkum_field_val must be equal to zero.\n\n"
    "NOTE: this byte is physically located at the end of the block (offset 127)" }
@@ -1059,14 +1060,14 @@ const char  dmt_std2_cl::Desc[] =
 
 const char stiXres8dsc[] = "Byte value: ((X-res / 8) - 31) : 256–2288 pixels, value 00 is "
 "reserved.\n"
-"Vertical resolution is calculated from X-res value, using pixel ratio";
+"Vertical resolution is calculated from X-res value, using image aspect ratio";
 const char stiVsyncDsc[] = "V-freq: (60–123 Hz).\n"
 "Bitfield (6bits) value is stored as Vfreq-60 (0-63)";
 const char stiAspRatioDsc[] = "Image aspect ratio:\n "
 "0b00 (0) =16:10;\n 0b01 (1) =4:3;\n 0b10 (2) =5:4;\n 0b11 (3) =16:9.\n"
 "EDID versions prior to 1.3 defined 0b00 as ratio 1:1.";
 const char stiDMT2B_Dsc[] = "VESA-DMT STD 2-byte Video Timing Code\n\n"
-"This field overlaps the fields 'X-res', 'V-freq' and 'asp_ratio' - it allows to select "
+"This field overlaps the fields 'X-res', 'V-freq' and 'asp_ratio' - it allows one to select "
 "standardised video code directly from value selector menu\n";
 
 const edi_field_t dmt_std2_cl::fields[] = {
@@ -1171,7 +1172,7 @@ const char  dmt_cvt3_cl::Name[] = "VESA-CVT 3-byte Timing Code";
 const char  dmt_cvt3_cl::Desc[] = "VESA-CVT 3-byte Timing Code";
 
 const char CVT3_DMT3B_Dsc[] = "VESA-CVT 3-byte Timing Code\n\n"
-"This field overlaps all other the fields in this group - it allows to select "
+"This field overlaps all other the fields in this group - it allows one to select "
 "standardised CVT-3 video code directly from value selector menu\n";
 
 const char CVT3_Yres_Dsc[] =
