@@ -2,7 +2,7 @@
  * Name:      EDID_dsc.cpp
  * Purpose:   EDID DTD and alternative descriptors
  * Author:    Tomasz Pawlak (tomasz.pawlak@wp.eu)
- * Copyright: Tomasz Pawlak (C) 2014-2024
+ * Copyright: Tomasz Pawlak (C) 2014-2025
  * License:   GPLv3+
  **************************************************************/
 
@@ -785,7 +785,7 @@ const edi_field_t mrl_cl::fields[] = {
    "Max pixel clock rate.\n"
    "Stored value: (pix_clk/10 MHz), range: 10..2550MHz\n\n"
    "If 'mrl_ext' == 0x04, that is, CVT support information is available, "
-   "then additional pixel clock bits from the extension are taken into accout (maxPixClk_apb)\n\n"
+   "then additional pixel clock bits from the extension are taken into account (maxPixClk_apb)\n\n"
    "The field handler reads from and writes to both those fields.\n"
    "With additional precision bits, the accuracy is increased to 0,25MHz\n\n"
    "Additionally, the field handler ensures that maxPixClk_apb never exceeds 10MHz, "
@@ -796,8 +796,8 @@ const edi_field_t mrl_cl::fields[] = {
    "Extended timing info: defines interpretation of bytes 12-17\n\n"
    "0x00: Default GTF supported if enabled in SPF (no secondary GTF)\n"
    "0x01: Range Limits only,\n"
-   "      in both cases bytes 12-17 should be set to 0x0A 20 20 20 20 20 20\n"
-   "0x02: GTF parameters in bytes 12-17\n"
+   "      in both cases bytes 12-17 should be set to 0x0A 20 20 20 20 20\n"
+   "0x02: Secondary GTF parameters in bytes 12-17\n"
    "0x04: VESA CVT support information in bytes 12-17\n\n"
    "other values are reserved"},
 };
@@ -833,10 +833,10 @@ const edi_field_t mrl_cl::fields_CVT[] = {
    "CVT standard minor version number, 4lsb, range 0..15" },
    {&EDID_cl::MRL_04_PixClk, 0, 12, 2, 6, F_BFD|F_FLT|F_MHZ|F_FR, 0, 63, "maxPixClk_apb",
    "Additional Precision Bits for use with byte9 'max_PixClk'\n"
-   "The aditional bits allow to increase accuracy of max_PixClk to 0.25MHz\n\n"
+   "The aditional bits are used to increase accuracy of max_PixClk to 0.25MHz\n\n"
    "Final max_PixClk=(max_PixClk-(maxPixClk_apb*0.25MHz))\n\n"
    "NOTE:\n"
-   "The max field value is 63*0.25=15.75MHz, but the hadler automatically adjusts max_PixClk value,"
+   "The max field value is 63*0.25=15.75MHz, but the field handler automatically adjusts max_PixClk value,"
    "so that maxPixClk_apb never exceed 10MHz, (bitfield value: 40*0.25MHz)." },
    {&EDID_cl::ByteVal, 0, mrl_offs(maxHApix_8lsb), 0, 1, F_BTE|F_INT, 0, 1023,
    "max_HApix",
@@ -1365,7 +1365,7 @@ extern const char* ET3_mode[]; //vid_fmt.cpp
 const char  et3_cl::CodN[] = "ET3";
 const char  et3_cl::Name[] = "Estabilished Timings 3";
 const char  et3_cl::Desc[] =
-"Addtional estabilished timings:\n"
+"Additional estabilished timings:\n"
 "Each bit indicates whether the corresponding timing is supported.";
 
 const char et3_cl::VerDsc[] = "ET3 version = 0x0A, other values reserved";
