@@ -2,16 +2,16 @@
  * Name:      EDID_main.cpp
  * Purpose:   EDID main functions and common field handlers
  * Author:    Tomasz Pawlak (tomasz.pawlak@wp.eu)
- * Copyright: Tomasz Pawlak (C) 2014-2024
+ * Copyright: Tomasz Pawlak (C) 2014-2025
  * License:   GPLv3+
  **************************************************************/
 
 #include "debug.h"
 #include "rcdunits.h"
-#ifndef idEDID_UTIL
+#ifndef idEDID_MAIN
    #error "EDID_base.cpp: missing unit ID"
 #endif
-#define RCD_UNIT idEDID_UTIL
+#define RCD_UNIT idEDID_MAIN
 #include "rcode/rcode.h"
 
 #include "wxedid_rcd_scope.h"
@@ -270,7 +270,7 @@ rcode EDID_cl::ParseDBC_TAG(u8_t *pinst, edi_grp_cl** pp_grp) {
                   //UNK-ET: Unknown Data Block (Extended Tag Code)
                   pgrp = new cea_unket_cl;
                   wxedid_RCD_SET_FAULT_VMSG(retU,
-                                            "[E!] CTA-861 DBC: invalid Extended Tag Code=%u",
+                                            "[E!] CTA-861 DBC: unknown Extended Tag Code=%u",
                                             etag);
             }
          }
@@ -280,7 +280,7 @@ rcode EDID_cl::ParseDBC_TAG(u8_t *pinst, edi_grp_cl** pp_grp) {
          //UNK-TC: Unknown Data Block (Tag Code)
          pgrp = new cea_unktc_cl;
          wxedid_RCD_SET_FAULT_VMSG(retU,
-                                   "[E!] CTA-861 DBC: invalid Tag Code=%u", tagcode);
+                                   "[E!] CTA-861 DBC: unknown Tag Code=%u", tagcode);
    }
 
   *pp_grp = pgrp;
@@ -400,8 +400,8 @@ rcode EDID_cl::ParseEDID_CEA() {
 
          if (p8_dtd < (pinst + blklen)) {
             wxedid_RCD_SET_FAULT_VMSG(retU,
-                                      "[E!] CTA-861: Collision: DTD offset=%u and DBC@offset=%u, len=%u",
-                                      dtd_offs, (u32_t) (calcGroupOffs(pinst) % sizeof(edid_t)), blklen);
+                 "[E!] CTA-861: Collision: DTD offset=%u and DBC@offset=%u, len=%u",
+                 dtd_offs, (u32_t) (calcGroupOffs(pinst) % sizeof(edid_t)), blklen);
             if (! b_ERR_Ignore) return retU;
             pGLog->PrintRcode(retU);
             RCD_SET_OK(retU);
@@ -420,8 +420,8 @@ rcode EDID_cl::ParseEDID_CEA() {
 
       if (pinst != p8_dtd) {
          wxedid_RCD_SET_FAULT_VMSG(retU,
-                                   "[E!] CTA-861: DTD offset=%u != DBC_end=%u",
-                                   dtd_offs, (u32_t) (calcGroupOffs(pinst) % sizeof(edid_t)) );
+              "[E!] CTA-861: DTD offset=%u != DBC_end=%u",
+              dtd_offs, (u32_t) (calcGroupOffs(pinst) % sizeof(edid_t)) );
          if (! b_ERR_Ignore) return retU;
          pGLog->PrintRcode(retU);
          RCD_SET_OK(retU);
@@ -445,8 +445,8 @@ rcode EDID_cl::ParseEDID_CEA() {
       if (num_dtd > 0) {
          if (max_dtd < num_dtd) {
             wxedid_RCD_SET_FAULT_VMSG(retU,
-                                      "[E!] CTA-861: insufficient space for declared number of native DTDs: %u, max: %u",
-                                      num_dtd, max_dtd);
+                 "[E!] CTA-861: insufficient space for declared number of native DTDs: %u, max: %u",
+                 num_dtd, max_dtd);
             if (! b_ERR_Ignore) return retU;
             pGLog->PrintRcode(retU);
             num_dtd = max_dtd;
@@ -457,8 +457,8 @@ rcode EDID_cl::ParseEDID_CEA() {
 
             if (pdtd->pix_clk == 0) {
                wxedid_RCD_SET_FAULT_VMSG(retU,
-                                         "[E!] CTA-861: missing mandatory DTD @ offset %u",
-                                         (u32_t) (reinterpret_cast <u8_t*> (pdtd) - EDID_buff.buff) );
+                    "[E!] CTA-861: missing mandatory DTD @ offset %u",
+                    (u32_t) (reinterpret_cast <u8_t*> (pdtd) - EDID_buff.buff) );
                if (! b_ERR_Ignore) return retU;
                pGLog->PrintRcode(retU);
                RCD_SET_OK(retU);
@@ -923,7 +923,7 @@ rcode EDID_cl::AssembleEDID() {
       //base EDID: consistency check
       if ((block == 0) && (blk_sz > 0)) {
          unk_t *unk;
-         //check if sizeis multiple of desc. size
+         //check if size is multiple of desc. size
          if ((blk_sz % sizeof(unk_t)) != 0) {
             RCD_RETURN_FAULT_MSG(retU, "[E!] Assebling FAILED, internal error");
          } else
