@@ -4,7 +4,7 @@
 #define RCD_UNITS_H 1
 
 #define idMAIN      1
-#define idEDID_UTIL 2
+#define idEDID_MAIN 2
 #define idEDID_BASE 3
 #define idEDID_DESC 4
 #define idCEA       5
